@@ -17,7 +17,7 @@ use constant VALIDATE_IP       => eval 'require Data::Validate::IP;1';
 
 use constant DEBUG => $ENV{JSON_VALIDATOR_DEBUG} || 0;
 
-our $VERSION = '0.76';
+our $VERSION = '0.77';
 our @EXPORT_OK = qw(validate_json);
 
 my $HTTP_SCHEME_RE = qr{^https?:};
@@ -543,8 +543,10 @@ sub _validate_type_object {
         $data->{$k} = $r->{default};
       }
       else {
-        push @errors, $self->_validate_type_enum($data->{$k}, _path($path, $k), $r) if $r->{enum};
-        push @errors, $self->_validate($data->{$k}, _path($path, $k), $r);
+        my @e = $self->_validate($data->{$k}, _path($path, $k), $r);
+        push @errors, @e;
+        push @errors, $self->_validate_type_enum($data->{$k}, _path($path, $k), $r)
+          if $r->{enum} and !@e;
       }
     }
   }
@@ -729,7 +731,7 @@ JSON::Validator - Validate data against a JSON schema
 
 =head1 VERSION
 
-0.76
+0.77
 
 =head1 SYNOPSIS
 
