@@ -54,13 +54,12 @@ sub validate_request {
 
     if (my @e = $self->_validate_request_value($p, $name => $value)) {
       push @errors, @e;
-      next;
     }
-
-    if ($exists or exists $p->{default}) {
+    elsif ($exists or exists $p->{default}) {
       $input->{$name} = $value;
+      $self->_set_request_parameter($c, $p, $value);
     }
-    if (!$exists and exists $p->{default}) {
+    elsif (!$exists and exists $p->{default}) {
       $self->_set_request_parameter($c, $p, $value);
     }
   }
@@ -112,7 +111,7 @@ sub _set_request_parameter {
     $c->req->params->merge($name => $value);
   }
   elsif ($in eq 'path') {
-    $c->match->stack->[-1] = $value;
+    $c->match->stack->[-1]{$name} = $value;
     $c->stash($name => $value);
   }
   elsif ($in eq 'formData') {
@@ -122,6 +121,9 @@ sub _set_request_parameter {
   elsif ($in eq 'header') {
     $c->req->headers->header($name => $value);
   }
+  elsif ($in eq 'body') {
+    return;    # no need to write body back
+  }
   else {
     die
       "Cannot set default for $in => $name. Please submit a ticket here: https://github.com/jhthorsen/mojolicious-plugin-openapi";
